==> SnappEmailApiClient-0.3.11b0.zip: SnappEmailApiClient-0.3.11b0/snapp_email/endpoints/action/ActionHideStream_18Endpoint.py <==
"""
Auto generated code

"""

import json
from snapp_email.datacontract.classes import ActionHideStream_18
from snapp_email.datacontract.utils import export_dict, fill


class ActionHideStream_18Endpoint:
    def __init__(self, api_client):
        self.api_client = api_client
    
    def options(self, accept_type=None):
        """
        Retrieve options available for resource 'ActionHideStream_18'.
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: ActionHideStream_18
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = 'action'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.action.hide.stream-v5.8+json',
            'Accept': 'application/vnd.4thoffice.action.hide.stream-v5.8+json' if accept_type is None else accept_type,
        }
        response = self.api_client.api_call('options', endpoint, url_parameters, add_headers)
        
        return fill(ActionHideStream_18, response.json())
    
    def create(self, obj, accept_type=None):
        """
        Hide stream resource.
        
        :param obj: Object to be persisted
        :type obj: ActionHideStream_18
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: ActionHideStream_18
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = 'action'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.action.hide.stream-v5.8+json',
            'Accept': 'application/vnd.4thoffice.action.hide.stream-v5.8+json' if accept_type is None else accept_type,
        }
        data = export_dict(obj)
        response = self.api_client.api_call('post', endpoint, url_parameters, add_headers, data=json.dumps(data))
        
        return fill(ActionHideStream_18, response.json())

==> SnappEmailApiClient-0.3.19.zip: SnappEmailApiClient-0.3.19/snapp_email/endpoints/action/ActionHideStream_18Endpoint.py <==
"""
Auto generated code

"""

import json
from snapp_email.datacontract.classes import ActionHideStream_18
from snapp_email.datacontract.utils import export_dict, fill


class ActionHideStream_18Endpoint:
    def __init__(self, api_client):
        self.api_client = api_client
    
    def options(self, impersonate_user_id=None, accept_type=None):
        """
        Retrieve options available for resource 'ActionHideStream_18'.
        
        :param impersonate_user_id: 
        :type impersonate_user_id: str
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: ActionHideStream_18
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = 'action'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.action.hide.stream-v5.8+json',
            'Accept': 'application/vnd.4thoffice.action.hide.stream-v5.8+json' if accept_type is None else accept_type,
        }
        response = self.api_client.api_call('options', endpoint, url_parameters, add_headers, impersonate_user_id=impersonate_user_id)
        
        return fill(ActionHideStream_18, response.json(), content_type=response.headers['Content-Type'])
    
    def create(self, obj, impersonate_user_id=None, accept_type=None):
        """
        Hide stream resource.
        
        :param obj: Object to be persisted
        :type obj: ActionHideStream_18
        
        :param impersonate_user_id: 
        :type impersonate_user_id: str
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: ActionHideStream_18
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = 'action'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.action.hide.stream-v5.8+json',
            'Accept': 'application/vnd.4thoffice.action.hide.stream-v5.8+json' if accept_type is None else accept_type,
        }
        data = export_dict(obj)
        response = self.api_client.api_call('post', endpoint, url_parameters, add_headers, impersonate_user_id=impersonate_user_id, data=json.dumps(data))
        
        return fill(ActionHideStream_18, response.json(), content_type=response.headers['Content-Type'])
